pub struct InnerStorage(/* private fields */);Expand description
InnerStorage: a catch-all type that allows using any Storage in parallel contexts.
Arc allows ref counting to share it between threads; RwLock makes sure there is only one writer possible (and a lot of readers); dyn Storage so we can init with anything that implements the Storage trait.
Implementations